import pygame, sys, os, random
from pygame.locals import *

pygame.init()

pygame.mouse.set_visible(False)

class sprite:
	def __init__(self,name,pos,health):
		self.name=name
		self.health=health
		self.tileset=[]
		self.pos=pygame.Rect(pos[0],pos[1],32,32)
		self.rect=pygame.Rect(pos[0]+8,pos[1]+24,16,8)
		for i in ['N','E','S','W']:
			for j in range(3):
				image=pygame.transform.scale(pygame.image.load('resources/graphics/sprites/'+name+'/'+i+str(j)+'.png'),(32,32))
				image.set_colorkey((255,255,255))
				self.tileset.append(image)
		self.moves=[False]*4
		self.tick=1
		self.direction=1
		self.shock_animation=[pygame.transform.scale(pygame.image.load('resources/graphics/effects/shock1.png'),(32,32)),pygame.transform.scale(pygame.image.load('resources/graphics/effects/shock2.png'),(32,32))]
		for s in self.shock_animation:
			s.set_colorkey((255,255,255))
		self.shock=0
				
	def update(self):		
		Game.room.image.blit(self.tileset[self.direction*3+self.tick],self.pos)
		
		if self.shock>0:
			Game.room.image.blit(self.shock_animation[self.shock%len(self.shock_animation)],self.pos)
			self.shock-=1
			if self.shock==0:
				self.health-=1
		
		if True in self.moves:
			self.tick+=1
			self.tick=self.tick%3
		else:
			self.tick=1
			
		self.move()
	
	def move(self):
	
		if self.moves[0]:
			self.pos[1]-=2
			
			if self.check_collide():
				self.pos[1]+=2
			
		if self.moves[1]:
			self.pos[0]+=2
			
			if self.check_collide():
				self.pos[0]-=2

		if self.moves[2]:
			self.pos[1]+=2
			
			if self.check_collide():
				self.pos[1]-=2

		if self.moves[3]:
			self.pos[0]-=2
			
			if self.check_collide():
				self.pos[0]+=2

		for i in range(4):
			if self.moves[i]:
				self.direction=i
				
	def check_collide(self):
		self.rect=pygame.Rect(self.pos[0]+8,self.pos[1]+24,16,8)
		if not pygame.Rect(32,32,576,576).contains(self.rect):
			return True
		for o in Game.room.objects:
			if self.rect.colliderect(o.pos):
				for p in Game.room.pushables:
					if p.name==o.name and p.pos==o.pos:
						p.push()
				return True
		crash = False	
		for s in Game.room.enemies:
			if s.sprite.rect.colliderect(self.rect) and s.sprite.rect != self.rect:
				crash=True	
		return crash
				
class player:
	def __init__(self,inventory,health):
		self.sprite=sprite('main',(int(Game.room.lines[1])*32,int(Game.room.lines[2])*32),health)
		self.inventory=inventory
		self.saved_inventory=[]
		for i in inventory:
			self.saved_inventory.append(i)
		self.inventory_index=0
		self.reach=pygame.Rect(self.sprite.pos[0]-2,self.sprite.pos[1]-2,36,36)
		self.message=''
		self.picked_up=False
		self.dead=0
		self.dead_image=pygame.transform.scale(pygame.image.load('resources/graphics/sprites/main/dead.png'),(32,32))
		self.dead_image.set_colorkey((255,255,255))
		
	def update(self):
		if self.dead == 0:
			self.sprite.update()
			
			if self.sprite.pos[0]+Game.room.scrollx	>500:
				Game.room.scrollx-=2
				
			if self.sprite.pos[0]+Game.room.scrollx	<160:
				Game.room.scrollx+=2
				
			if self.sprite.pos[1]+Game.room.scrolly	>500:
				Game.room.scrolly-=2
				
			if self.sprite.pos[1]+Game.room.scrolly	<160:
				Game.room.scrolly+=2
	
			
			self.reach=pygame.Rect(self.sprite.pos[0]-2,self.sprite.pos[1]-2,36,36)
			
			if self.message == '':			
				for item in Game.room.items:
					if self.reach.colliderect(item.pos):
						self.message='Press "J" to pick up '+item.name
						
				for e in Game.room.events:
					for object in Game.room.objects:
						if self.reach.colliderect(object.pos) and object.name==e.object:
							if e.goal_needed in Game.room.goals or e.goal_needed == '':
								self.message='Press "J" to '+e.text		
					
				Game.GUI.write(self.message)
				self.message=''	
				
			else:
				Game.GUI.write(self.message)
			
			if self.sprite.health<1:
				self.dead=50
				
		else:
			self.dead-=1
			Game.room.image.blit(self.dead_image,self.sprite.pos)	
			Game.GUI.write('You died!  Try again...')
			if self.dead==0:
				Game.new_level(self.saved_inventory,10)
			
	def pick_up(self):
		short=0
		self.reach=pygame.Rect(self.sprite.pos[0]-2,self.sprite.pos[1]-2,36,36)		
		for i in range(len(Game.room.items)):
			if i < len(Game.room.items)-short:
				if Game.room.items[i].pos.colliderect(self.reach):
					if '' in self.inventory:
						for j in range(len(self.inventory)):
							if self.inventory[j]=='':
								self.inventory[j]=Game.room.items[i]
								self.message='You picked up '+self.inventory[j].name
								break
						Game.room.items=Game.room.items[:i]+Game.room.items[i+1:]
						short+=1
					else:
						Game.player.message='No space in inventory'
						
		for e in Game.room.events:
			for object in Game.room.objects:
				if self.reach.colliderect(object.pos) and object.name==e.object:
					if not e.test():
						if e.goal_needed in Game.room.goals or e.goal_needed == '':
							self.message=e.error_text
						
	def drop(self):
		if self.inventory[self.inventory_index] != '':
			self.message='You dropped '+self.inventory[self.inventory_index].name
			self.inventory[self.inventory_index].pos=pygame.Rect(self.sprite.rect[0],self.sprite.rect[1],16,16)
			Game.room.items.append(self.inventory[self.inventory_index])
			self.inventory[self.inventory_index]=''		
			
	def throw(self):
		throwable=['a can of cooldrink']
		
		for i in range(len(self.inventory)):
			if self.inventory[i]!='' and self.inventory[i].name=='a space gun':
				Game.room.thrown_items.append(thrown_item(item('shot',(self.sprite.pos[0]+8,self.sprite.pos[1])),self.sprite.direction))
				break
			else:
				if self.inventory[i]!='' and self.inventory[i].name in throwable:
					self.inventory[i].pos[0]=self.sprite.pos[0]+8
					self.inventory[i].pos[1]=self.sprite.pos[1]
					Game.room.thrown_items.append(thrown_item(self.inventory[i],self.sprite.direction))
					self.inventory[i]=''
					break								

class enemy:
	def __init__(self,pos):
		self.sprite=sprite('evil',(pos[0],pos[1]),1)
		self.shock=0
		self.shocked=False
		
	def update(self):
		self.sprite.update()
		
		if Game.player.sprite.pos[1]+16<self.sprite.pos[1]:
			self.sprite.moves[0]=True
		else:
			self.sprite.moves[0]=False	
			
		if Game.player.sprite.pos[0]-16>self.sprite.pos[0]:
			self.sprite.moves[1]=True
		else:
			self.sprite.moves[1]=False	
			
		if Game.player.sprite.pos[1]-16>self.sprite.pos[1]:
			self.sprite.moves[2]=True
		else:
			self.sprite.moves[2]=False	
			
		if Game.player.sprite.pos[0]+16<self.sprite.pos[0]:
			self.sprite.moves[3]=True
		else:
			self.sprite.moves[3]=False	
			
		self.shock+=1		
		self.shock=self.shock%10
		
		if self.shock==0:
			self.shocked=False			
		
		if self.sprite.pos.colliderect(Game.player.sprite.pos) and self.shock==0:
			Game.player.sprite.shock=5
			self.shocked=True
			
		if self.shocked:
			self.sprite.moves=[False]*4			
						
class object:
	def __init__(self,name,pos):
		self.name=name
		self.pos=pygame.Rect(pos[0],pos[1],32,32)
		self.image=pygame.transform.scale(pygame.image.load('resources/graphics/tiles/objects/'+name+'.png'),(32,32))
		self.image.set_colorkey((255,255,255))	
		
	def update(self):
		Game.room.image.blit(self.image,self.pos)

class item:
	def __init__(self,name,pos):		
		self.name=name
		self.pos=pygame.Rect(pos[0],pos[1],16,16)
		self.image=pygame.transform.scale(pygame.image.load('resources/graphics/items/'+name+'.png'),(16,16))
		self.image.set_colorkey((255,255,255))
		self.icon=pygame.transform.scale(pygame.image.load('resources/graphics/items/'+name+'.png'),(16,16))
		self.icon.blit(Game.GUI.icon_frame,(0,0))	
		
	def update(self):
		Game.room.image.blit(self.image,self.pos)

class event:
	def __init__(self,object,goal_needed,item_needed,goal,item,text,error_text,replace):
		self.object=object
		self.goal_needed=goal_needed
		self.item_needed=item_needed
		self.goal=goal
		self.item=item
		self.text=text
		self.error_text=error_text
		self.replace=replace
		
	def test(self):
		g=False
		ob=False
		it=False
		
		if len(self.goal_needed)> 1:
			if self.goal_needed in Game.room.goals:
				g=True
		else:
			g=True
		
		for o in Game.room.objects:
			if o.name==self.object:
				if Game.player.reach.colliderect(o.pos):
					ob=True		
					
		if len(self.item_needed)> 1:						
			for i in Game.player.inventory:
				if i != '':
					if i.name == self.item_needed:
						it=True
		else:
			it=True	
					
		if g and ob and it:
			if len(self.goal)> 1:
				Game.room.goals.append(self.goal)
			
			if self.item!='':
				if '' in Game.player.inventory:
					for j in range(len(Game.player.inventory)):
						if Game.player.inventory[j]=='':
							Game.player.inventory[j]=item(self.item,(0,0))
							break
				else:
					Game.player.message='No space in inventory'
					Game.room.items.append(item(self.item,(Game.player.sprite.rect[0]+random.randint(0,16),Game.player.sprite.rect[1]+random.randint(0,16))))
			
			if len(self.replace)> 1:
				for o in Game.room.objects:
					if o.name==self.object:
						o.name=self.replace
						o.image=pygame.transform.scale(pygame.image.load('resources/graphics/tiles/objects/'+self.replace+'.png'),(32,32))
						o.image.set_colorkey((255,255,255))		
									
			return True
		else:
			return False

class pushable:
	def __init__(self,name,x,y):
		self.name=name
		self.pos=pygame.Rect(x*32,y*32,32,32)
		
	def push(self):
		for o in Game.room.objects:
			if o.name==self.name and o.pos==self.pos and Game.player.sprite.pos.colliderect(self.pos):
				if Game.player.sprite.moves[0] and abs(Game.player.sprite.rect[1]-self.pos[1])<32:
					self.pos[1]-=2
					
					if self.check_collide(o.pos):
						self.pos[1]+=2
					
				if Game.player.sprite.moves[1] and abs(Game.player.sprite.rect[1]-self.pos[1])<32:
					self.pos[0]+=2
					
					if self.check_collide(o.pos):
						self.pos[0]-=2
		
				if Game.player.sprite.moves[2] and abs(Game.player.sprite.rect[0]-self.pos[0])<32:
					self.pos[1]+=2
					
					if self.check_collide(o.pos):
						self.pos[1]-=2
		
				if Game.player.sprite.moves[3] and abs(Game.player.sprite.rect[1]-self.pos[1])<32:
					self.pos[0]-=2
					
					if self.check_collide(o.pos):
						self.pos[0]+=2	
						
				o.pos=self.pos
						
	def check_collide(self,other_pos):
		if not pygame.Rect(32,32,576,576).contains(self.pos):
			return True
		for o in Game.room.objects:
			if self.pos.colliderect(o.pos) and o.pos!=other_pos:
				return True		
		return False
		
class thrown_item:
	def __init__(self,item,direction):
		self.item=item
		self.direction=direction
		self.speed=60
		
	def update(self):
		self.item.update()
	
		if self.direction==0:
			self.item.pos[1]-=self.speed/6
			
		if self.direction==1:
			self.item.pos[0]+=self.speed/6
			
		if self.direction==2:
			self.item.pos[1]+=self.speed/6
			
		if self.direction==3:
			self.item.pos[0]-=self.speed/6	
		
		if not self.item.name=='shot':	
			self.speed-=1
					
class GUI:
	def __init__(self):
		self.icon_frame=pygame.image.load('resources/graphics/GUI/inventory.png')
		self.icon_frame.set_colorkey((255,255,255))
		self.icon_frame_highlighted=pygame.image.load('resources/graphics/GUI/inventory_highlighted.png')
		self.icon_frame_highlighted.set_colorkey((255,255,255))
		self.inventory=pygame.Surface((144,16))
		self.life_bar=pygame.Surface((160,16))
		self.inventory.fill((255,255,255))
		self.font=pygame.font.Font('resources/fonts/MIKRC___.ttf', 12)
		self.message=self.font.render('', True, (255,255,255), (0,0,0))
		self.message_rect=self.message.get_rect()
		self.message_rect.midtop=(320,627)
		self.life=pygame.image.load('resources/graphics/GUI/life.png')
	
	def update(self):
		self.inventory.fill((255,255,255))
		for i in range(9):
			if Game.player.inventory[i] != '':
				self.inventory.blit(Game.player.inventory[i].icon,(i*16,0))
			else:
				self.inventory.blit(self.icon_frame,(i*16,0))
		self.inventory.blit(self.icon_frame_highlighted,(Game.player.inventory_index*16,0))
		
		self.life_bar.fill((255,255,255))
		for i in range(Game.player.sprite.health):
			self.life_bar.blit(self.life,(16*i,0))
			
		for i in range(10):
			self.life_bar.blit(self.icon_frame,(16*i,0))
		
		Game.window.display.blit(Game.room.image,(Game.room.scrollx,Game.room.scrolly))
		pygame.draw.rect(Game.window.display,(0,0,0),(0,0,640,16))
		pygame.draw.rect(Game.window.display,(0,0,0),(0,640-16,640,16))
		Game.window.display.blit(self.inventory,(0,0))
		Game.window.display.blit(self.life_bar,(640-160,0))
		Game.window.display.blit(self.message,self.message_rect)		
		
	def write(self,text):
		self.message=self.font.render(text, True, (255,255,255), (0,0,0))
		self.message_rect=self.message.get_rect()
		self.message_rect.midtop=(320,640-14)
		
												
class room:
	def __init__(self,number):
		self.number=number
		self.background=pygame.Surface((640,640))
		self.image=pygame.Surface((640,640))
		self.scrollx=0
		self.scrolly=0
		
		self.objects=[]
		f=file('resources/levels/'+str(number)+'.abc','r')
		l=f.readlines()
		f.close()
		a=l[0].split(':')
		r=[]
		for i in a:
			r.append(i.split(','))
		
		for y in range(20):
			for x in range(20):
				if r[y][x]!='':
					self.objects.append(object(r[y][x],(x*32,y*32)))		
		
		self.lines=l			
		
		self.items=[]
		self.events=[]
		self.goals=[]
		self.pushables=[]
		self.enemies=[]
		self.thrown_items=[]
		self.intro=[]
		
		if len(l[7]) > 1:
			self.intro=l[7].split(',')
		
		if len(l[6]) > 1:
			for en in l[6].split(':'):
				e=en.split(',')
				self.enemies.append(enemy((int(e[0])*32,int(e[1])*32)))
		
		if len(l[5]) > 1:
			for pu in l[5].split(':'):
				p=pu.split(',')
				self.pushables.append(pushable(p[0],int(p[1]),int(p[2])))
		
		if len(l[4]) > 1:
			for ev in l[4].split(':'):
				e=ev.split(',')
				self.events.append(event(e[0],e[1],e[2],e[3],e[4],e[5],e[6],e[7]))

		if len(l[3]) > 1:		
			for i in self.lines[3].split(':'):
				it=i.split(',')
				self.items.append(item(it[0],(int(it[1]),int(it[2]))))
								
		floorplan = ['01111111111111111112','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','34444444444444444445','67777777777777777778']						
		
		for y in range(20):
			for x in range(20):
				if Game.level==5 and floorplan[y][x]=='4':
					im=pygame.transform.scale(pygame.image.load('resources/graphics/tiles/background/9.png'),(32,32))
				else:					
					im=pygame.transform.scale(pygame.image.load('resources/graphics/tiles/background/'+floorplan[y][x]+'.png'),(32,32))
				im.set_colorkey((255,255,255))
				self.background.blit(im,(x*32,y*32))
				
		pygame.display.update()
		
	def update(self):
		self.image.blit(self.background,(0,0))
		for o in self.objects:
			o.update()
		for i in self.items:
			i.update()	
		for i in self.enemies:
			i.update()
		for i in self.thrown_items:
			i.update()		
		
		short=0	
		for i in range(len(self.thrown_items)):
			if i < len(self.thrown_items)-short:
				hit = False
				for e in self.enemies:
					if self.thrown_items[i].item.pos.colliderect(e.sprite.pos) and not hit:
						hit = True
						e.sprite.shock=10					
						break
						
				for o in range(len(self.objects)):
					ob=self.objects[o]
					if self.thrown_items[i].item.pos.colliderect(ob.pos) and not hit and ob.name=='fire extinguisher':
						hit = True
						self.objects[o]=object('fire extinguisher broken',ob.pos)
						self.items.append(item('a fire extinguisher',(388,16)))					
						break		
						
				if hit or self.thrown_items[i].speed<10 or not pygame.Rect(32,32,576,576).contains(self.thrown_items[i].item.pos):	
					if self.thrown_items[i].speed<10:
						self.items.append(self.thrown_items[i].item)
					self.thrown_items=self.thrown_items[:i]+self.thrown_items[i+1:]
					short+=1
					
		short=0	
		for i in range(len(self.enemies)):
			if i < len(self.enemies)-short:
				if self.enemies[i].sprite.health<1:	
					self.enemies=self.enemies[:i]+self.enemies[i+1:]
					short+=1
			
class window:
	def __init__(self,size):
		self.size=size
		self.display=pygame.display.set_mode(self.size)
		self.fullscreen=False
		pygame.display.set_caption('Overtime')
		pygame.display.set_icon(pygame.image.load('resources/graphics/GUI/icon.png'))
		
	def update(self):
		#self.display.blit(Game.room.image,(Game.room.scrollx,Game.room.scrolly))
		pygame.display.update()
		self.display.fill((0,0,0))
		
	def set_fullscreen(self):
		self.fullscreen = not self.fullscreen
		if self.fullscreen:
			pygame.display.set_mode(self.size,pygame.FULLSCREEN)
		else:
			pygame.display.set_mode(self.size)
		
class settings:
	def __init__(self):
		self.keys=[K_w,K_d,K_s,K_a,K_j,K_k,K_h]
		
class game:
	def __init__(self):
		self.window=window((640,640))
		self.level=1
		self.name=''	
		self.playing=True
		self.clock=pygame.time.Clock()
		self.settings=settings()
		self.GUI=GUI()
		
	def loop(self):
		self.room.update()
		self.player.update()
		self.GUI.update()
		self.window.update()
		self.clock.tick(30)
		
		for event in pygame.event.get():
			if event.type==QUIT:
				play()
				
			if event.type==KEYDOWN:
				if event.key==K_ESCAPE:
					play()
				
				if event.key==K_RETURN:
					pause()	
					
				for i in range(4):
					if event.key == self.settings.keys[i]:
						self.player.sprite.moves[i]=True
				
				if event.key>48 and event.key<58:
					self.player.inventory_index=event.key-49	
				
				if event.key==self.settings.keys[4]:
					self.player.pick_up()
					
				if event.key==self.settings.keys[5]:
					self.player.drop()	
					
				if event.key==self.settings.keys[6]:
					self.player.throw()
									
			if event.type==KEYUP:
				for i in range(4):
					if event.key == self.settings.keys[i]:
						self.player.sprite.moves[i]=False	
						
				if event.key==self.settings.keys[4] or event.key==self.settings.keys[5]:
					Game.player.message=''
					
		if 'level finished' in self.room.goals:
			self.level+=1
			self.new_level(self.player.inventory,self.player.sprite.health)	
			
		if 'game finished' in self.room.goals:
			credits()
			play()		
	
	def new_level(self,inventory,health):
		self.room=room(self.level)		
		self.player=player(inventory,health)	
		
		f=file('resources/saved games/'+Game.name+'.zzz','w')
		save=str(self.level)+':'
		for i in self.player.inventory:
			if i != '':
				save+=i.name+','
			else:
				save+=','
		save=save[:-1]+':'+str(self.player.sprite.health)		
		f.write(save)
		f.close()
		intro(self.room.intro)				

def intro(lines):
	index=0
	Game.room.update()
	Game.player.update()
	while index<len(lines):	
		Game.GUI.write(lines[index])
	
		Game.GUI.update()
		Game.window.update()
	
		for event in pygame.event.get():
			if event.type==QUIT:
				play()
				
			if event.type==KEYDOWN:
				if event.key==K_ESCAPE:
					play()
				
				index+=1
				
									
def play():
	global Game
	Game=game()
	Game.name=get_name()
	f=file('resources/saved games/'+Game.name+'.zzz','r')
	lines=f.read().split(':')
	f.close()
	Game.level=int(lines[0])
	inventory=[]
	for i in lines[1].split(','):
		if i!='':
			inventory.append(item(i,(0,0)))	
		else:
			inventory.append('')			
			
	Game.new_level(inventory,int(lines[2]))	
	while Game.playing == True:
		Game.loop()		

def get_name():
	global Menu

	Menu=menu([option('New game','resources/graphics/items/a paper.png',0,'Type a game name...'),option('Saved game','resources/graphics/items/a cd.png',1,'Type a saved game name'),option('Instructions','resources/graphics/items/a book.png',2,''),option('Options','resources/graphics/items/a screwdriver.png',3,''),option('Exit','resources/graphics/items/a can of cooldrink.png',4,'')])
	
	directory = os.listdir('resources/saved games/')
	saved_games=[]
	for i in directory:
		if not os.path.isdir('resources/graphics/tiles/objects/'+i):
			saved_games.append(i[:-4])
	
	new=''
	saved=''
	
	saved_index=0
	
	while True:
		for event in pygame.event.get():
			if event.type==QUIT:
				pygame.quit()
				sys.exit()
				
			if event.type==KEYDOWN:
				Menu.options[1].text='Type a saved game name'
			
				if event.key==K_ESCAPE:
					pygame.quit()
					sys.exit()
					
				if event.key==K_UP:
					Menu.index-=1
					
				if event.key==K_DOWN:
					Menu.index+=1
				
				if Menu.index==1 and len(saved_games)>0:	
						
					if event.key==K_LEFT:
						saved_index-=1
						
						saved_index=saved_index%len(saved_games)
						saved=saved_games[saved_index]
						Menu.options[1].name=saved
						
					if event.key==K_RIGHT:
						saved_index+=1
						
						saved_index=saved_index%len(saved_games)
						saved=saved_games[saved_index]
						Menu.options[1].name=saved
				
				if (event.key<123 and event.key>96) or event.key==K_SPACE:
					if Menu.index==0:
						new+=chr(event.key)	
						Menu.options[0].name=new
						
					if Menu.index==1:
						saved+=chr(event.key)	
						Menu.options[1].name=saved
						
				if event.key==K_BACKSPACE:
					if Menu.index==0:
						if new != '':
							new=new[:-1]
							
						Menu.options[0].name=new
						
					if Menu.index==1:
						if saved != '':
							saved=saved[:-1]	
							
						Menu.options[1].name=saved		
							
				if event.key==K_RETURN:
					if Menu.index==0 and new!='':
						f=file('resources/saved games/'+new+'.zzz','w')
						f.write('1:'+'an ID card'+8*','+':'+'10')
						f.close()
						return new
						
					if Menu.index==1:
						if saved in saved_games:
							return saved
									
						Menu.options[1].text='No such saved game exists!'
						
					if Menu.index==2:
						instructions()
					
					if Menu.index==3:	
						options()
						
					if Menu.index==4:
						pygame.quit()
						sys.exit()
								
				Menu.index=Menu.index%5
					
		Menu.update()
	
	return ''###		

def options():
	global Options_menu

	Options_menu=menu([option('Fullscreen','resources/graphics/tiles/objects/picture.png',0,'Options'),option('Back','resources/graphics/tiles/objects/door.png',1,'Options')])
	
	while True:
		for event in pygame.event.get():
			if event.type==QUIT:
				pygame.quit()
				sys.exit()
				
			if event.type==KEYDOWN:
				if event.key==K_ESCAPE:
					return
					
				if event.key==K_UP:
					Options_menu.index-=1
					
				if event.key==K_DOWN:
					Options_menu.index+=1
							
				if event.key==K_RETURN:
					if Options_menu.index==0:
						Game.window.set_fullscreen()
						
					if Options_menu.index==1:
						return
								
				Options_menu.index=Options_menu.index%2
					
		Options_menu.update()
		
def pause():
	global Options_menu

	Pause_menu=menu([option('Instructions','resources/graphics/items/a book.png',0,'Pause'),option('Options','resources/graphics/items/a screwdriver.png',1,'Pause'),option('Menu','resources/graphics/items/an ID card.png',2,'Pause'),option('Back','resources/graphics/tiles/objects/door.png',3,'Pause')])
	
	while True:
		for event in pygame.event.get():
			if event.type==QUIT:
				return
				
			if event.type==KEYDOWN:
				if event.key==K_ESCAPE:
					return
					
				if event.key==K_UP:
					Pause_menu.index-=1
					
				if event.key==K_DOWN:
					Pause_menu.index+=1
							
				if event.key==K_RETURN:
					if Pause_menu.index==0:
						instructions()
					
					if Pause_menu.index==1:
						options()
					
					if Pause_menu.index==2:	
						play()
						
					if Pause_menu.index==3:
						return
								
				Pause_menu.index=Pause_menu.index%4
					
		Pause_menu.update()
			
class menu:
	def __init__(self,options):
		self.options=options
		self.index=0
		self.icon=pygame.transform.scale(pygame.image.load('resources/graphics/GUI/inventory_highlighted.png'),(32,32))
		self.icon.set_colorkey((255,255,255))
		self.font=pygame.font.Font('resources/fonts/MIKRC___.ttf', 20)
		
	def update(self):
		for o in self.options:
			o.update()
		
		message=self.font.render(self.options[self.index].text, True, (255,255,255), (0,0,0))
		message_rect=message.get_rect()
		message_rect.midtop=(320,100)	
		
		Game.window.display.blit(message,message_rect)		
				
		Game.window.display.blit(self.icon,(100,200+80*self.index))	
		Game.window.update()
		
class option:
	def __init__(self,name,image,number,text):
		self.name=name
		self.number=number
		self.image=pygame.transform.scale(pygame.image.load(image),(32,32))
		self.image.set_colorkey((255,255,255))
		self.text=text
	
		
	def update(self):
		Game.window.display.blit(self.image,(100,200+80*self.number))
		
		message=Menu.font.render(self.name, True, (255,255,255), (0,0,0))
		message_rect=message.get_rect()
		message_rect.topleft=(150,202+80*self.number)	
		
		Game.window.display.blit(message,message_rect)			

def instructions():
	f=file('resources/instructions.hjk','r')
	lines=f.readlines()
	f.close()

	font=pygame.font.Font('resources/fonts/MIKRC___.ttf', 15)
	
	while True:
		for event in pygame.event.get():
			if event.type==QUIT:
				return
				
			if event.type==KEYDOWN:		
				return
							
		for i in range(len(lines)):
			text=font.render(lines[i][:-1], True, (255,255,255), (0,0,0))
			text_rect=text.get_rect()
			text_rect.topleft=(20,20+20*i)	
			
			Game.window.display.blit(text,text_rect)
				
		Game.window.update()		

def credits():
	f=file('resources/credits.hjk','r')
	lines=f.readlines()
	f.close()

	font=pygame.font.Font('resources/fonts/MIKRC___.ttf', 15)
	
	scroll=0
	
	gun=False
	for i in Game.player.inventory:
		if i!='':
			if i.name=='a space gun':
				gun=True
		
	while True:
		for event in pygame.event.get():
			if event.type==QUIT:
				return
				
			if event.type==KEYDOWN:		
				return
							
		for i in range(len(lines)):
			text=font.render(lines[i][:-1], True, (255,255,255), (0,0,0))
			if i==12 and gun:
				text=font.render('and got a space gun', True, (255,255,255), (0,0,0))
			text_rect=text.get_rect()
			text_rect.topleft=(20,20+20*i+scroll)	
			
			Game.window.display.blit(text,text_rect)
		
		scroll-=1	
					
		Game.window.update()
		Game.clock.tick(30)			
		
		if scroll<-900:
			return
							
play()